import { r as registerInstance, h } from './index-fec85944.js';
import './messages-7ba0bfcd.js';
import { C as ConftokenProvider, s as sql } from './utils-f5a4ba73.js';
import { $ } from './jquery-434b2007.js';
import './location-c41cbf0a.js';
import { p as parser } from './parser-b14108fa.js';

const flxHomeCss = "";

const FlxHome = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    componentWillLoad() {
        this.title = '';
        this.body = '';
        this.header = '';
        this.footer = '';
        this.loadData();
        $(window).off('popstate.home').on('popstate.home', () => {
            if (document.location.href.toLowerCase().indexOf('/home') > 0) {
                this.loadData();
            }
        });
    }
    refresh(ev) {
        this.loadData().then(() => { ev.target.complete(); });
    }
    loadData() {
        return ConftokenProvider.config().then(async (cnf) => {
            this.title = '';
            this.body = '';
            this.header = '';
            this.footer = '';
            if (cnf && cnf.homePage) {
                let page = cnf.homePage;
                if (page.SQLSentence) {
                    sql.getTable(page.SQLSentence).then(async (table) => {
                        if (table && table.rows && table.rows.length > 0) {
                            this.title = await parser.recursiveCompile(sql.getRow(table, 0), page.title, this);
                        }
                        this.body = await this.getRows(page, table, null, this);
                    });
                }
                else {
                    this.title = await parser.recursiveCompile(null, page.title, this);
                    if (page.header) {
                        this.header = await parser.recursiveCompile(null, page.header, this);
                    }
                    if (page.body) {
                        this.body = await parser.recursiveCompile(null, page.body, this);
                    }
                    if (page.footer) {
                        this.footer = await parser.recursiveCompile(null, page.footer, this);
                    }
                }
            }
        });
    }
    async getRows(page, table, defaults, ctx) {
        let rendered = '';
        if (table && table.rows && table.rows.length > 0) {
            if (page.header && page.header != '') {
                this.header = await parser.recursiveCompile(sql.getRow(table, 0), page.header, ctx);
            }
            if (page.body && page.body != '') {
                for (let i = 0; i < table.rows.length; i++) {
                    rendered += await parser.recursiveCompile(sql.getRow(table, i), page.body, ctx);
                }
            }
            if (page.footer && page.footer != '') {
                this.footer = await parser.recursiveCompile(sql.getRow(table, 0), page.footer, this);
            }
        }
        else {
            if (page.empty && page.empty != '') {
                rendered = await parser.recursiveCompile(defaults, page.empty, this);
            }
            else {
                rendered = 'No data found';
            }
        }
        return rendered;
    }
    render() {
        return [
            h("ion-header", null, h("ion-toolbar", { color: "header", class: "ion-text-center" }, h("ion-buttons", { slot: "start" }, h("ion-menu-button", { color: "outstanding" })), h("ion-title", null, h("span", { id: "menuTitle" }, this.title)))),
            h("ion-content", null, h("ion-refresher", { slot: "fixed", id: "refresher", onIonRefresh: (ev) => { this.refresh(ev); } }, h("ion-refresher-content", null)), h("div", { id: "mainHeader", innerHTML: this.header }), h("div", { id: "mainBody", innerHTML: this.body }), h("div", { id: "mainHeader", innerHTML: this.header }))
        ];
    }
};
FlxHome.style = flxHomeCss;

export { FlxHome as flx_home };
