import { r as registerInstance, h } from './index-fec85944.js';
import { m as msg } from './messages-7ba0bfcd.js';
import { n as nav } from './navigation-1d81491e.js';
import { s as sql, C as ConftokenProvider, u as util } from './utils-f5a4ba73.js';
import { $ } from './jquery-434b2007.js';
import './location-c41cbf0a.js';
import { p as parser } from './parser-b14108fa.js';

const flxListCss = "";

const FlxList = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.pageElements = 100;
        this.currentPage = 0;
        this.searchValue = '';
    }
    watchHandler() {
        this.filterData();
    }
    componentWillLoad() {
        this.load();
        $(window).off('popstate.list').on('popstate.list', () => {
            if (document.location.href.toLowerCase().indexOf('/list/') > 0) {
                this.load();
            }
        });
    }
    load() {
        this.object = (this.object) ? decodeURIComponent(this.object) : null;
        this.pageName = (this.pageName) ? decodeURIComponent(this.pageName) : null;
        this.filter = (this.filter) ? decodeURIComponent(this.filter) : null;
        this.defaults = (this.defaults) ? decodeURIComponent(this.defaults) : null;
        this.body = new Array();
        this.footer = '';
        this.header = '';
        this.title = '';
        this.loadData();
    }
    filterData(filter) {
        this.currentPage = 0;
        let sentence = sql.addWhere(this.page.SQLSentence, this.filter);
        let params = [];
        if (this.page && this.page.ShowSearchBar && this.page.SQLSearchFilter && this.searchValue) {
            for (let i = 0; i < this.page.SQLSearchFilter.match(/(@findstring)/gmi).length; i++) {
                params.push(this.searchValue);
            }
            sentence = sql.addWhere(sentence, this.page.SQLSearchFilter.replace(/(@findstring)/gmi, '?'));
        }
        sentence = sql.addWhere(sentence, this.additional);
        sentence = sql.addWhere(sentence, filter);
        if (this.page && this.page.SQLOrderBy) {
            sentence = sql.addOrderBy(sentence, this.page.SQLOrderBy);
        }
        sql.getTable(sentence, params).then(async (table) => {
            this.table = table;
            this.body = await this.getRows(this.confObj, this.page, this.table, null, this, false);
        });
    }
    refresh(ev) {
        this.loadData().then(() => {
            if (ev && ev.target && ev.target.complete) {
                ev.target.complete();
            }
        });
    }
    async loadMore() {
        let infiniteScroll = document.getElementById('infiniteScroll');
        if (infiniteScroll) {
            infiniteScroll.disabled = true;
        }
        this.currentPage += 1;
        let newItems = await this.getRows(this.confObj, this.page, this.table, null, this, false);
        let currentBody = document.getElementById('mainBody');
        newItems.map((itm) => {
            currentBody.append(itm);
        });
        if (infiniteScroll) {
            infiniteScroll.complete();
        }
    }
    loadData() {
        this.currentPage = 0;
        this.table = null;
        this.page = null;
        return ConftokenProvider.config().then(async (cnf) => {
            this.confObj = cnf.objectConfig[this.object];
            let page = parser.findTemplate(this.confObj, 'list', this.pageName);
            if (!page) {
                let item = document.createElement('ion-item');
                if (this.pageName) {
                    item.innerHTML = 'Can\'t find page ' + this.object;
                }
                else {
                    item.innerHTML = 'Can\'t find any page for object ' + this.object;
                }
                this.body = [item];
                return;
            }
            this.title = page.title;
            let sentence = sql.addWhere(page.SQLSentence, this.filter);
            let params = [];
            if (page && page.ShowSearchBar && page.SQLSearchFilter && this.searchValue) {
                for (let i = 0; i < page.SQLSearchFilter.match(/(@findstring)/gmi).length; i++) {
                    params.push(this.searchValue);
                }
                sentence = sql.addWhere(sentence, page.SQLSearchFilter.replace(/(@findstring)/gmi, '?'));
            }
            sentence = sql.addWhere(sentence, this.additional);
            if (page && page.SQLOrderBy) {
                sentence = sql.addOrderBy(sentence, page.SQLOrderBy);
            }
            await sql.getTable(sentence, params).then(async (table) => {
                if (table && table.rows && table.rows.length > 0) {
                    this.title = await parser.recursiveCompile(sql.getRow(table, 0), page.title, this);
                }
                this.table = table;
                this.page = page;
                let def = null;
                if (this.defaults) {
                    def = util.parseJSON(this.defaults);
                }
                this.body = await this.getRows(this.confObj, this.page, this.table, def, this, true);
            });
        }).catch(e => {
            msg.showError(e);
        });
    }
    async getRows(confObj, page, table, defaults, ctx, first) {
        let infiniteScroll = document.getElementById('infiniteScroll');
        let newItems = new Array();
        if (table && table.rows && table.rows.length > 0) {
            if (first && page.header && page.header != '') {
                this.header = await parser.recursiveCompile(sql.getRow(table, 0), page.header, ctx);
            }
            if (page.body && page.body != '') {
                let i = this.currentPage * this.pageElements;
                let lastElement = ((this.currentPage + 1) * this.pageElements);
                while (i < lastElement && i < table.rows.length) {
                    if (infiniteScroll) {
                        infiniteScroll.disabled = false;
                    }
                    let rendered = '';
                    let row = sql.getRow(table, i);
                    row['objIdent'] = util.getPrimaryKeysFilter(confObj, row);
                    rendered += await parser.recursiveCompile(row, page.body, ctx);
                    let item = document.createElement('ion-item-sliding');
                    item.innerHTML = rendered;
                    newItems.push(item);
                    i += 1;
                }
                if (i < lastElement) {
                    if (infiniteScroll) {
                        infiniteScroll.disabled = true;
                    }
                }
            }
            if (first && page.footer && page.footer != '') {
                this.footer = await parser.recursiveCompile(sql.getRow(table, 0), page.footer, ctx);
            }
        }
        else if (first) {
            if (first && page.header && page.header != '') {
                this.header = await parser.recursiveCompile(defaults, page.header, ctx);
            }
            let item = document.createElement('ion-item');
            if (page.empty && page.empty != '') {
                item.innerHTML = await parser.recursiveCompile(defaults, page.empty, ctx);
            }
            else {
                item.innerHTML = 'No data found';
            }
            newItems.push(item);
            if (first && page.footer && page.footer != '') {
                this.footer = await parser.recursiveCompile(defaults, page.footer, ctx);
            }
        }
        return newItems;
    }
    async onSearchChange(ev, value) {
        if (value) {
            this.searchValue = '%' + value + '%';
        }
        else {
            this.searchValue = '';
        }
        this.refresh(ev);
    }
    render() {
        return [
            h("ion-header", null, h("ion-toolbar", { color: "header", class: "ion-text-center" }, h("ion-buttons", { slot: "start" }, h("ion-menu-button", { color: "outstanding" })), h("ion-buttons", { slot: "end" }, h("ion-button", { color: "outstanding", onClick: () => { nav.goBack(); } }, h("ion-icon", { slot: "icon-only", name: "undo" }))), h("ion-title", null, h("span", { id: "menuTitle" }, this.title)))),
            h("ion-header", null, ((this.page && this.page.ShowSearchBar && this.page.SQLSearchFilter)
                ? h("ion-searchbar", { debounce: 1000, value: this.searchValue.replace(/^\%+|\%+$/g, ''), onIonClear: (ev) => { this.onSearchChange(ev, ''); }, onIonChange: (ev) => { this.onSearchChange(ev, ev.currentTarget.value.toLowerCase()); }, animated: true, "show-cancel-button": "focus" })
                : '')),
            h("ion-header", { innerHTML: this.header }),
            h("ion-content", null, h("ion-refresher", { slot: "fixed", id: "refresher", onIonRefresh: (ev) => { this.refresh(ev); } }, h("ion-refresher-content", { "pulling-icon": "arrow-dropdown", refreshingSpinner: "bubbles" })), h("ion-list", { id: "mainBody" }, this.body.map((itm) => {
                if (itm.tagName.toLocaleLowerCase() == 'ion-item-sliding') {
                    return h("ion-item-sliding", { innerHTML: itm.innerHTML });
                }
                else {
                    return h("ion-item", { innerHTML: itm.innerHTML });
                }
            })), h("ion-infinite-scroll", { threshold: "500px", id: "infiniteScroll", onIonInfinite: () => { this.loadMore(); } }, h("ion-infinite-scroll-content", { loadingSpinner: "bubbles", loadingText: "Loading..." }))),
            h("ion-footer", { innerHTML: this.footer })
        ];
    }
    static get watchers() { return {
        "additional": ["watchHandler"]
    }; }
};
FlxList.style = flxListCss;

export { FlxList as flx_list };
