import { r as registerInstance, h, c as getElement } from './index-fec85944.js';
import './messages-7ba0bfcd.js';
import { s as sql } from './utils-f5a4ba73.js';
import { $ } from './jquery-434b2007.js';
import './location-c41cbf0a.js';
import { p as parser } from './parser-b14108fa.js';

const flxSqllistCss = "flx-sqllist{}";

const FlxSqllist = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.currentPage = 0;
        this.pageElements = 100;
        this.params = [];
    }
    watchHandler() {
        this.filterData();
    }
    async refresh(ev) {
        return this.loadData().then(() => { ev.target.complete(); });
    }
    async filterData(filter) {
        this.currentPage = 0;
        let sentence = sql.addWhere(this.sqlsentence, this.filter);
        sentence = sql.addWhere(sentence, this.additional);
        sentence = sql.addWhere(sentence, filter);
        sentence = sql.addOrderBy(sentence, this.orderby);
        sql.getTable(sentence, this.params).then(async (table) => {
            this.table = table;
            this.body = await this.getRows(this.table, null, this, false);
        });
    }
    componentWillLoad() {
        this.load();
    }
    load() {
        this.bodyTemplate = $(this.element).find('.bodyTemplate').text();
        this.body = new Array();
        this.footer = '';
        this.header = '';
        this.loadData();
    }
    async loadMore() {
        let infiniteScroll = document.getElementById('infiniteScroll');
        if (infiniteScroll) {
            infiniteScroll.disabled = true;
        }
        this.currentPage += 1;
        let newItems = await this.getRows(this.table, null, this, false);
        let currentBody = document.getElementById('mainBody');
        newItems.map((itm) => {
            currentBody.append(itm);
        });
        if (infiniteScroll) {
            infiniteScroll.complete();
        }
    }
    async loadData() {
        this.currentPage = 0;
        this.table = null;
        let sentence = sql.addWhere(this.sqlsentence, this.filter);
        sentence = sql.addWhere(sentence, this.additional);
        return sql.getTable(sentence).then(async (table) => {
            this.table = table;
            this.body = await this.getRows(this.table, null, this, true);
        });
    }
    async getRows(table, defaults, ctx, first) {
        let infiniteScroll = document.getElementById('infiniteScroll');
        let newItems = new Array();
        if (table && table.rows && table.rows.length > 0) {
            if (first && this.headerTemplate && this.headerTemplate != '') {
                this.header = await parser.recursiveCompile(sql.getRow(table, 0), this.headerTemplate, ctx);
            }
            if (this.bodyTemplate && this.bodyTemplate != '') {
                let i = this.currentPage * this.pageElements;
                let lastElement = ((this.currentPage + 1) * this.pageElements);
                while (i < lastElement && i < table.rows.length) {
                    if (infiniteScroll) {
                        infiniteScroll.disabled = false;
                    }
                    let row = sql.getRow(table, i);
                    let item = document.createElement('ion-item');
                    item.innerHTML = await parser.recursiveCompile(row, this.bodyTemplate, ctx);
                    ;
                    newItems.push(item);
                    i += 1;
                }
                if (i < lastElement) {
                    if (infiniteScroll) {
                        infiniteScroll.disabled = true;
                    }
                }
            }
            if (first && this.footerTemplate && this.footerTemplate != '') {
                this.footer = await parser.recursiveCompile(sql.getRow(table, 0), this.footerTemplate, this);
            }
        }
        else if (first) {
            let item = document.createElement('ion-item');
            if (this.emptyTemplate && this.emptyTemplate != '') {
                item.innerHTML = await parser.recursiveCompile(defaults, this.emptyTemplate, this);
            }
            else {
                item.innerHTML = 'No data found';
            }
            newItems.push(item);
        }
        return newItems;
    }
    render() {
        return [
            h("ion-header", { innerHTML: this.header }),
            h("ion-list", { id: "mainBody" }, this.body.map((itm) => {
                return h("ion-item", { innerHTML: itm.innerHTML });
            })),
            h("ion-infinite-scroll", { threshold: "500px", id: "infiniteScroll", onIonInfinite: () => { this.loadMore(); } }, h("ion-infinite-scroll-content", { loadingSpinner: "bubbles", loadingText: "Loading..." })),
            h("ion-footer", { innerHTML: this.footer })
        ];
    }
    get element() { return getElement(this); }
    static get watchers() { return {
        "additional": ["watchHandler"]
    }; }
};
FlxSqllist.style = flxSqllistCss;

export { FlxSqllist as flx_sqllist };
