import { r as registerInstance, h } from './index-fec85944.js';
import { m as msg } from './messages-7ba0bfcd.js';
import { n as nav } from './navigation-1d81491e.js';
import { C as ConftokenProvider, m as moment, a as ConftokenService } from './utils-f5a4ba73.js';
import { $ } from './jquery-434b2007.js';

const flxSyncCss = "";

const FlxSync = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.lastSync = '-';
    }
    componentWillLoad() {
        this.refresh();
    }
    refresh() {
        ConftokenProvider.config().then((cnf) => {
            if (cnf && cnf.lastSync) {
                this.lastSync = moment(cnf.lastSync).format('L LT');
            }
        });
    }
    sendData() {
        let cnf = new ConftokenService();
        this.popOverInfo(cnf).then(() => {
            cnf.sendDataStart().catch((err) => {
                msg.showError(err);
                $('ion-popover')[0].dismiss();
            });
        });
    }
    syncTemplates() {
        let cnf = new ConftokenService();
        cnf.getAppTemplates().catch((err) => {
            msg.showError(err);
        }).then(() => {
            msg.success('Templates updated');
        });
    }
    getAllData(forced) {
        let cnf = new ConftokenService();
        this.popOverInfo(cnf).then(() => {
            cnf.getAppConfiguration(forced).catch((err) => {
                debugger;
                msg.showError(err);
                $('ion-popover')[0].dismiss();
            });
        });
    }
    async popOverInfo(cnf) {
        let info = document.createElement('ion-grid');
        let popover = Object.assign(document.createElement('ion-popover'), {
            component: info,
            translucent: true,
            backdropDismiss: false
        });
        document.body.appendChild(popover);
        popover.onclose = (() => { info.innerHTML = ''; });
        let s1 = cnf.onStatusChange.subscribe((itm) => {
            this.infoCreateorUpdateItem(info, itm);
            console.log(itm);
        });
        let s2 = cnf.onRowsReceivedChange.subscribe((itm) => {
            this.infoCreateorUpdateItem(info, itm);
            console.log(itm);
        });
        let s3 = cnf.onFinish.subscribe((syncRes) => {
            if (syncRes.success) {
                this.refresh();
                popover.dismiss().then(() => { popover = null; });
            }
            else {
                popover.backdropDismiss = true;
                if (syncRes.error) {
                    msg.showError(syncRes.error);
                }
            }
            s1.unsubscribe();
            s2.unsubscribe();
            s3.unsubscribe();
        });
        return popover.present();
    }
    infoCreateorUpdateItem(info, itm) {
        if (itm) {
            let id = itm.tableName;
            let infoRow = info.querySelector('[tag="' + id + '"]');
            if (!infoRow) {
                infoRow = document.createElement('ion-row');
                infoRow.setAttribute('tag', id);
                info.appendChild(infoRow);
            }
            this.updateInfo(infoRow, itm);
            if (itm.state == 'error') {
                infoRow.onclick = (() => { msg.showError(itm.lastError); });
            }
        }
    }
    updateInfo(container, itm) {
        let rows = container.querySelector('.rows');
        if (itm.state == 'pending' && rows) {
            rows.innerHTML = itm.rows;
        }
        else {
            switch (itm.state) {
                case 'pending':
                    container.innerHTML = `<ion-col>${itm.tableName}</ion-col><ion-col style="text-align:right"><b class="rows">${itm.rows}</b></ion-col>`;
                    break;
                case 'finish':
                    container.innerHTML = `<ion-col>${itm.tableName}</ion-col><ion-col style="text-align:right"><ion-label color="success"><ion-icon name="checkmark-circle"></ion-icon></ion-label></ion-col>`;
                    break;
                case 'error':
                    container.innerHTML = `<ion-col>${itm.tableName}</ion-col><ion-col class="danger" style="text-align:right"><ion-label color="danger"><ion-icon name="close"></ion-icon></ion-label></ion-col>`;
                    break;
            }
        }
    }
    render() {
        return [
            h("ion-header", null, h("ion-toolbar", { color: "header", class: "ion-text-center" }, h("ion-buttons", { slot: "start" }, h("ion-button", { color: "outstanding", onClick: () => { nav.goHome(); } }, h("ion-icon", { slot: "icon-only", name: "home" }))), h("ion-buttons", { slot: "end" }, h("ion-button", { color: "outstanding", onClick: () => { nav.goLogin(); } }, h("ion-icon", { slot: "icon-only", name: "exit" }))), h("ion-title", null, h("span", null, "Sync")))),
            h("ion-content", { color: "light", class: "ion-padding" }, h("ion-grid", { fixed: true }, h("ion-row", null, h("ion-col", { size: "12" }, h("h5", null, h("ion-icon", { name: "timer" }), " Last sync on:"), h("h2", null, this.lastSync))), h("ion-row", null, h("ion-col", { size: "12" }, h("div", { class: "square-container", color: "outstanding" }, h("div", { class: "square" }, h("div", { class: "content", onClick: () => this.getAllData(false) }, h("i", { class: "flx-icon icon-sincronize" }), h("h6", null, "Refresh Data"))), h("div", { class: "square" }, h("div", { class: "content", onClick: () => this.getAllData(true) }, h("i", { class: "flx-icon icon-reload1" }), h("h6", null, "Overwrite Data")))), h("div", { class: "square-container", color: "outstanding" }, h("div", { class: "square" }, h("div", { class: "content", onClick: () => this.sendData() }, h("i", { class: "flx-icon icon-arrow-31" }), h("h6", null, "Send Data"))), h("div", { class: "square" }, h("div", { class: "content", onClick: () => this.syncTemplates() }, h("i", { class: "flx-icon icon-templates" }), h("h6", null, "Sync Templates"))))))))
        ];
    }
};
FlxSync.style = flxSyncCss;

export { FlxSync as flx_sync };
