import { r as registerInstance, h } from './index-fec85944.js';
import { m as msg } from './messages-7ba0bfcd.js';
import { n as nav } from './navigation-1d81491e.js';
import { C as ConftokenProvider, s as sql, u as util } from './utils-f5a4ba73.js';
import { $ } from './jquery-434b2007.js';
import './location-c41cbf0a.js';
import { p as parser } from './parser-b14108fa.js';

const flxViewCss = "";

const FlxView = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    componentWillLoad() {
        this.object = (this.object) ? decodeURIComponent(this.object) : null;
        this.pageName = (this.pageName) ? decodeURIComponent(this.pageName) : null;
        this.filter = (this.filter) ? decodeURIComponent(this.filter) : null;
        this.defaults = (this.defaults) ? decodeURIComponent(this.defaults) : null;
        this.loadData();
        $(window).off('popstate.view').on('popstate.view', () => {
            if (document.location.href.toLowerCase().indexOf('/view/') > 0) {
                this.loadData();
            }
        });
    }
    refresh(ev) {
        this.loadData().then(() => { ev.target.complete(); });
    }
    loadData() {
        return ConftokenProvider.config().then(async (cnf) => {
            let confObj = cnf.objectConfig[this.object];
            let page = parser.findTemplate(confObj, 'view', this.pageName);
            let sentence = page.SQLSentence;
            if (page.SQLSentence.toLowerCase().indexOf('where') >= 0) {
                sentence += ' and ' + this.filter;
            }
            else {
                sentence += ' WHERE ' + this.filter;
            }
            await sql.getTable(sentence).then(async (table) => {
                if (table && table.rows && table.rows.length > 0) {
                    this.title = await parser.recursiveCompile(sql.getRow(table, 0), page.title, this);
                }
                this.body = await this.getRows(confObj, page, table, null, this);
            });
        }).catch(e => {
            msg.showError(e);
        });
    }
    async getRows(confObj, page, table, defaults, ctx) {
        let rendered = '';
        if (table && table.rows && table.rows.length > 0) {
            let row = sql.getRow(table, 0);
            row['objIdent'] = util.getPrimaryKeysFilter(confObj, row);
            if (page.header && page.header != '') {
                rendered += await parser.recursiveCompile(row, page.header, ctx);
            }
            if (page.body && page.body != '') {
                rendered += await parser.recursiveCompile(row, page.body, ctx);
            }
            if (page.footer && page.footer != '') {
                rendered += await parser.recursiveCompile(row, page.footer, this);
            }
        }
        else {
            if (page.empty && page.empty != '') {
                rendered = await parser.recursiveCompile(defaults, page.empty, this);
            }
            else {
                rendered = 'No data found';
            }
        }
        return rendered;
    }
    render() {
        return [
            h("ion-header", null, h("ion-toolbar", { color: "header", class: "ion-text-center" }, h("ion-buttons", { slot: "start" }, h("ion-menu-button", { color: "outstanding" })), h("ion-buttons", { slot: "end" }, h("ion-button", { color: "outstanding", onClick: () => { nav.goBack(); } }, h("ion-icon", { slot: "icon-only", name: "undo" }))), h("ion-title", null, h("span", { id: "menuTitle" }, this.title)))),
            h("ion-content", null, h("ion-refresher", { slot: "fixed", id: "refresher", onIonRefresh: (ev) => { this.refresh(ev); } }, h("ion-refresher-content", null)), h("div", { id: "mainBody", innerHTML: this.body }))
        ];
    }
};
FlxView.style = flxViewCss;

export { FlxView as flx_view };
